==> ZeBook_0.3.tar.gz: ZeBook/man/weather_FranceWest.Rd <==
\docType{data}
\name{weather_FranceWest}
\alias{weather_FranceWest}
\title{Weather serie for West of France from NASA POWER agroclimatology}
\format{a \code{RangedData} instance, 1 row per day.}
\source{
  \url{http://power.larc.nasa.gov/}
}
\description{
  This contemporary daily climate dataset for West of
  France covers the period 1st January 1984 to 31 December
  2011. The precipitation data is limited to the period
  Jan-1997 Aug-2009, thus only 12 complete years of data
  were available for analysis involving precipitation(1997
  to 2009). It cover main part of West part of France
  defined as a rectangle. The dataset was extrated from the
  NASA Langley Research Center POWER Project which provide
  agroclimatology dataset (Chandler et al., 2004). It was
  funded through the NASA Earth Science Directorate Applied
  Science Program This climate datasetcontains daily
  estimates of precipitation, mean, minimum and maximum
  temperature, relative humidity, dew point, solar
  radiation and wind speed with global coverage at one
  degree resolution (approximately 111 km at the equator).
  The NASA POWER agroclimatology data are derived from
  various sources: solar radiation from satellite
  observations, meteorological data from the Goddard Earth
  Observing System global assimilation model version 4
  (GEOS-4), and precipitation from the Global Precipitation
  Climate Project and Topical Rainfall Measurement Mission.
  A full description can be found at
  \url{http://power.larc.nasa.gov/common/MethodologySSE6/POWER_Methodology_Content.html}
}
\keyword{datasets}

==> ZeBook_0.4.tar.gz: ZeBook/man/weather_FranceWest.Rd <==
\docType{data}
\name{weather_FranceWest}
\alias{weather_FranceWest}
\title{Weather serie for West of France from NASA POWER agroclimatology}
\format{a \code{RangedData} instance, 1 row per day.}
\source{
  \url{http://power.larc.nasa.gov/}
}
\description{
  This contemporary daily climate dataset for West of
  France covers the period 1st January 1984 to 31 December
  2011. The precipitation data is limited to the period
  Jan-1997 Aug-2009, thus only 12 complete years of data
  were available for analysis involving precipitation(1997
  to 2009). It cover main part of West part of France
  defined as a rectangle. The dataset was extracted from
  the NASA Langley Research Center POWER Project which
  provide agroclimatology dataset (Chandler et al., 2004).
  It was funded through the NASA Earth Science Directorate
  Applied Science Program This climate dataset contains
  daily estimates of precipitation, mean, minimum and
  maximum temperature, relative humidity, dew point, solar
  radiation and wind speed with global coverage at one
  degree resolution (approximately 111 km at the equator).
  The NASA POWER agroclimatology data are derived from
  various sources: solar radiation from satellite
  observations, meteorological data from the Goddard Earth
  Observing System global assimilation model version 4
  (GEOS-4), and precipitation from the Global Precipitation
  Climate Project and Topical Rainfall Measurement Mission.
  A full description can be found at
  \url{http://power.larc.nasa.gov/common/MethodologySSE6/POWER_Methodology_Content.html}
}
\keyword{datasets}
